#! /bin/tcsh -f
#
#  make a disappearing smile
#
#

set grid = 32

set logfile = /dev/tty

set seed = 1

make_maphead.com -grid $grid $grid $grid -axis X Y Z P1 -cell 20 20 20 90 90 90 >>& $logfile

set head = `ls -l header.map | awk '{print $5}'`



foreach face ( smiley frowny )

convert -flip -compress none ${face}.png ${face}.pgm
awk 'NR>=4{for(i=1;i<=NF;++i)print 1-$i/255}' ${face}.pgm | floatgen >! ${face}.bin

cp header.map ${face}.map
foreach z ( `seq 1 30` )
cat ${face}.bin >> ${face}.map
end
dd if=/dev/zero bs=4096 count=2 >> ${face}.map

cp header.map ${face}.map
dd if=/dev/zero bs=4096 count=2 >> ${face}.map
cat ${face}.bin >> ${face}.map
cat ${face}.bin >> ${face}.map
cat ${face}.bin >> ${face}.map
cat ${face}.bin >> ${face}.map
dd if=/dev/zero bs=4096 count=26 >> ${face}.map

mapmask mapin ${face}.map mapout temp.map << EOF
scale factor 1
axis Z X Y
EOF
mv temp.map ${face}.map

end
pick.com smiley.map 

head -c $head smiley.map >! header.map



rm sum.map allstats_vs_seed.txt

foreach seed ( `seq 1 10` )

cp header.map rand.map
echo "$grid $seed" |\
awk '{g=$1;srand($2);\
      for(z=0;z<g;++z)\
      for(y=0;y<g;++y)\
      for(x=0;x<g;++x){\
        print rand();\
      }\
     }' |\
floatgen >> rand.map

echo maps mult | mapmask mapin1 rand.map mapin2 smiley.map mapout test.map >> $logfile

cp test.map true.map

float_add -header $head test.map -reject 6 | tee prestats.log >>& $logfile
set prestats = `awk '/^max|^mean|^median/{print $3,$6}' prestats.log`

set cellvolume = `echo 20 | awk '{print $1**3}'`
set F000 = `echo $prestats 20 | awk '{print $3*$NF**3}'`

rm -f test.mtz >& /dev/null
phenix.map_to_structure_factors test.map d_min=0.5 b_blur=0 scale_max=None \
  output_file_name=test.mtz >> $logfile

rm -f test_1.map >& /dev/null
phenix.fft test.mtz gridding=32,32,32 scale=volume output.prefix=test extension=map >>& $logfile

set mean = `echo | mapdump mapin test_1.map | awk '/Mean dens/{print $NF}'`
set offset = `echo $prestats $mean | awk '{print $3-$NF}'`
set offset = 0
mapmask mapin test_1.map mapout ffted.map << EOF >>& $logfile
scale factor 1 $offset
AXIS Z X Y
EOF

float_add -header $head ffted.map -reject 6 | tee stats.log >>& $logfile
set stats = `awk '/^max|^mean|^median/{print $3,$6}' stats.log`

float_add -header $head ffted.map test.map -scale2 -1 -reject 6 -outfile diff.map | tee diffstats.log >>& $logfile
set diffstats = `awk '/^max|^mean|^median/{print $3,$6}' diffstats.log`

echo maps mult | mapmask mapin1 diff.map mapin2 smiley.map mapout masked.map >> $logfile

if(! -e sum.map) float_add -header $head masked.map -scale1 0 -outfile sum.map

float_add -header $head masked.map sum.map -scale2 1 -outfile sum.map | tee sumstats.log >>& $logfile
set sumstats = `awk '/^max|^mean|^median/{print $3,$6}' sumstats.log`

echo "$sumstats    $diffstats   $reso $grid $seed" | tee -a allstats_vs_seed.txt
# max min mean rms med mad   max min mean rms med mad   reso grid radius shoulder scale
# 1        2   3    4   5   6    7   8    9   10  11  12   13   14    15    16       17    18

end

# one final subtraction without mask
cp sum.map test.map

rm f v.mtz >& /dev/null
phenix.map_to_structure_factors sum.map d_min=0.5 b_blur=0 scale_max=None \
  output_file_name=test.mtz >> $logfile

rm -f test_1.map >& /dev/null
phenix.fft test.mtz gridding=32,32,32 scale=volume output.prefix=test extension=map >>& $logfile

set mean = `echo | mapdump mapin test_1.map | awk '/Mean dens/{print $NF}'`
set offset = `echo $prestats $mean | awk '{print $3-$NF}'`
set offset = 0
mapmask mapin test_1.map mapout ffted.map << EOF >>& $logfile
scale factor 1 $offset
AXIS Z X Y
EOF

float_add -header $head ffted.map -reject 6 | tee stats.log >>& $logfile
set stats = `awk '/^max|^mean|^median/{print $3,$6}' stats.log`

float_add -header $head ffted.map test.map -scale2 -1 -reject 6 -outfile diff.map | tee diffstats.log >>& $logfile
set diffstats = `awk '/^max|^mean|^median/{print $3,$6}' diffstats.log`

cp diff.map final.map

cp final.map cheshire_smile.map



echo AXIS Z X Y | mapmask mapin final.map mapout sfallme.map

sfall mapin sfallme.map hklout sfalled.mtz << EOF >> $logfile
mode sfcalc mapin
reso 0.5
SFSG 1
EOF

refmac5 mapin final.map hklout refmac.mtz << EOF
mode sfcalc
EOF

phenix.map_to_structure_factors final.map d_min=0.5 b_blur=0 scale_max=None \
  output_file_name=phenix.mtz >> $logfile

cad hklin1 sfalled.mtz hklin2 refmac.mtz hklin3 phenix.mtz hklout all3.mtz << EOF
labin file 1 E1=FC 
labin file 2 E1=Fout0
labin file 3 E1=F
EOF

mtz2txt all3.mtz

awk 'NR<14{next} ! /,,/{print $4,$5}' all3.csh | tee sfall_vs_refmac.txt | correlate.awk 
awk 'NR<14{next} ! /,,/{print $4,$6}' all3.csh | tee sfall_vs_phenix.txt  | correlate.awk 
awk 'NR<14{next} ! /,,/{print $5,$6}' all3.csh | tee refmac_vs_phenix.txt  | correlate.awk 


phenix.fft sfalled.mtz gridding=32,32,32 scale=volume include_fmodel=True \
  output.prefix=sfalled extension=map >>& $logfile
mv sfalled_fcalc.map sfalled.map
phenix.fft refmac.mtz gridding=32,32,32 scale=volume include_fmodel=True \
  output.prefix=refmaced extension=map >>& $logfile
mv refmaced_1.map refmaced.map
phenix.fft phenix.mtz gridding=32,32,32 scale=volume include_fmodel=True \
  output.prefix=phenixed extension=map >>& $logfile
mv phenixed_1.map phenixed.map

float_add -header $head sfalled.map -outfile dummy.map | tee fftedstats_sfall.log >>& $logfile
float_add -header $head refmaced.map -outfile v.map | tee fftedstats_refmac.log >>& $logfile
float_add -header $head phenixed.map -outfile dummy.map | tee fftedstats_phenix.log >>& $logfile


float_add -header $head sfalled.map final.map -scale2 -1 -reject 6 -outfile sfall_fftdiff.map | tee diffstats_sfall.log >>& $logfile
float_add -header $head refmaced.map final.map -scale2 -1 -reject 6 -outfile refmac_fftdiff.map | tee diffstats_refmac.log >>& $logfile
float_add -header $head phenixed.map final.map -scale2 -1 -reject 6 -outfile phenix_fftdiff.map | tee diffstats_phenix.log >>& $logfile


foreach map ( sum test ffted diff )
  echo $grid |\
  awk '{g=$1;h=int(g/2);print "xyzlim",h,h,h,h,1,g}' |\
   mapmask mapin ${map}.map mapout line.map >> $logfile
  map2pdb.com line.map  >> $logfile
  awk '/^ATOM/{print $9,$NF}' mapdump.pdb >! ${map}_trace.txt
  echo $grid |\
  awk '{g=$1;h=int(g/2);print "xyzlim",1,g,h,h,h,h}' |\
   mapmask mapin ${map}.map mapout line.map >> $logfile
  map2pdb.com line.map  >> $logfile
  awk '/^ATOM/{print $7,$NF}' mapdump.pdb >! ${map}_xtrace.txt
  map2pdb.com ${map}.map  >> $logfile
  awk '$2==$3 && ($4-0.5)**2<0.01{print $2,$NF}' mapdump.frac >! ${map}_diag.txt 
  map2pdb.com ${map}.map  >> $logfile
  awk '$2==$3 && $3==$4{print $2,$NF}' mapdump.frac >! ${map}_diag3.txt 
end



float_func -func fft final.map -header $head -outfile fft.map



sfall mapin fft.map hklout test.mtz << EOF >> $logfile
mode sfcalc mapin
reso 0.5
SFSG 1
EOF


float_add -header $head frowny.map cheshire_smile.map -output temp.map 
echo scale factor 1 | mapmask mapin temp.map mapout hidden_frown.map

echo AXIS Z X Y | mapmask mapin hidden_frown.map mapout sfallme.map
sfall mapin sfallme.map hklout test.mtz << EOF >> $logfile
mode sfcalc mapin
reso 0.5
SFSG 1
EOF
fft hklin test.mtz mapout new.map << EOF >> $logfile
labin F1=FC PHI=PHIC
GRID $grid $grid $grid
EOF

rm f temp.mtz >& /dev/null
phenix.map_to_structure_factors hidden_frown.map d_min=0.5 b_blur=0 scale_max=None \
  output_file_name=temp.mtz >> $logfile

rm -f new_1.map >& /dev/null
phenix.fft temp.mtz gridding=32,32,32 scale=volume output.prefix=new extension=map >>& $logfile


coot -p pick.pdb --map cheshire_smile.map --map frowny.map --map smiley.map &


convert -crop 400x400+150 -border 1 before.png square1.png
convert -crop 400x400+150 -border 1  after.png square2.png
convert +append square1.png square2.png before_and_after.png 



